/* Sistemas Integrados TECNISA
   Planejamento Alimentao Industrial

Nome: QTDE_BRUTA_PRODUTO.SQL                                                   
                                                                            
Descrio:                                                                 
Retorna a quantidade bruta de um produto a partir da quantidade na receita 
de acordo com os parmetros de utilizao do fator de correo e coco.   

Criao:                                                                   
20/01/99 - Ederson                                                         

Manutenes:                                                               
__/__/99 - _______ - ___________                                           
                                                                            
P_CDFILIAL   - Cdigo da Filial (utilizado para pesquisar os parmetros    
               de utilizao dos fatores de correo e coco.
P_QTORIGINAL - Quantidade Original (lquida).                              
P_VRPEFATCOC - Fator de Coco.                                            
P_VRPEFATCOR - Fator de Correo.                                          

*/

CREATE OR REPLACE
FUNCTION QTDE_BRUTA_PRODUTO
  (P_CDFILIAL   IN FILIAL.CDFILIAL%TYPE,
   P_QTORIGINAL IN NUMBER,
   P_VRPEFATCOC IN NUMBER,
   P_VRPEFATCOR IN NUMBER,
   P_IDUTILFATCOC IN VARCHAR2 DEFAULT ' ',
   P_IDUTILFATCOR IN VARCHAR2 DEFAULT ' ',
   P_IDTIPCALCFAT IN VARCHAR2 DEFAULT ' ') RETURN NUMBER IS

   V_QTDECALC NUMBER;

   V_IDUTILFATCOC  PARAMPLANEJA.IDUTILFATCOC%TYPE;
   V_IDUTILFATCOR  PARAMPLANEJA.IDUTILFATCOR%TYPE;
   V_IDTIPCALCFAT  PARAMPLANEJA.IDTIPCALCFAT%TYPE;

   CURSOR C_PARAMPLANEJA IS
    SELECT
       IDUTILFATCOR,
       IDUTILFATCOC,
       IDTIPCALCFAT
    FROM
       PARAMPLANEJA
    WHERE
       (CDFILIAL = P_CDFILIAL);

BEGIN
   /* - Inicializa os indentificadores com os valores default --------------- */

   IF P_IDUTILFATCOR = ' ' THEN
      OPEN C_PARAMPLANEJA;

      FETCH C_PARAMPLANEJA
      INTO V_IDUTILFATCOR,
           V_IDUTILFATCOC,
           V_IDTIPCALCFAT;

      IF C_PARAMPLANEJA%NOTFOUND THEN
         V_IDUTILFATCOC := 'S';
         V_IDUTILFATCOR := 'S';
         V_IDTIPCALCFAT := 'T';
      END IF;

      CLOSE C_PARAMPLANEJA;
   ELSE
      V_IDUTILFATCOC := P_IDUTILFATCOC;
      V_IDUTILFATCOR := P_IDUTILFATCOR;
      V_IDTIPCALCFAT := P_IDTIPCALCFAT;
   END IF;

   /* Faz a converso da unidade do produto na receita */

   V_QTDECALC := P_QTORIGINAL;

   IF (V_IDTIPCALCFAT <> 'S') THEN
      IF (V_IDUTILFATCOR <> 'N') AND (V_IDUTILFATCOC = 'N') THEN
         V_QTDECALC := P_QTORIGINAL * (100 / (100 - P_VRPEFATCOR));
      END IF;
      IF (V_IDUTILFATCOR = 'N') AND (V_IDUTILFATCOC <> 'N') THEN
         V_QTDECALC := P_QTORIGINAL * (100 / (100 + P_VRPEFATCOC));
      END IF;
      IF (V_IDUTILFATCOR <> 'N') AND (V_IDUTILFATCOC <> 'N') THEN
         V_QTDECALC := P_QTORIGINAL * (100 / (100 + P_VRPEFATCOC));
         V_QTDECALC := V_QTDECALC * (100 / (100 - P_VRPEFATCOR));
      END IF;
   ELSE
      IF (V_IDUTILFATCOR <> 'N') AND (V_IDUTILFATCOC = 'N') THEN
         V_QTDECALC := P_QTORIGINAL * (1 + (P_VRPEFATCOR / 100));
      END IF;
      IF (V_IDUTILFATCOR = 'N') AND (V_IDUTILFATCOC <> 'N') THEN
         V_QTDECALC := P_QTORIGINAL * (1 + (P_VRPEFATCOC / 100));
      END IF;
      IF (V_IDUTILFATCOR <> 'N') AND (V_IDUTILFATCOC <> 'N') THEN
         V_QTDECALC := P_QTORIGINAL * (1 + (P_VRPEFATCOC / 100));
         V_QTDECALC := V_QTDECALC * (1 + (P_VRPEFATCOR / 100));
      END IF;
   END IF;

   --P_QTDE_BRUT_PRODUTO := V_QTDECALC;

   RETURN(V_QTDECALC);
END;
/



-- VERSAO --
BEGIN ATUVEROBJ('QTDE_BRUTA_PRODUTO','4.05.133'); END;
/

