/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/*                                                                            */
/* Pedidos e Expedio                                                        */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Nome: 9600_EXPTRG_ATUALIZA_PEDIDO                                          */
/*                                                                            */
/* Descrio:                                                                 */
/* Quando um item da NF gerado pelo Sistema Expedio  excludo, o campo     */
/* QTEXPITEMPED (quantidade expedida) da tabela ITEMPEDIDO  atualizado.      */
/* Se necessrio, a situao do item de pedido e do pedido so atualizados.   */
/*                                                                            */
/* Criao:                                                                   */
/* 09/12/1999 - Rogrio Cosendey Labanca                                      */
/*                                                                            */
/*                                                                            */
/******************************************************************************/

/******************************************************************************/
/* @C:\WIN_V4\SQL\END_CONV\ORACLE\9600_EXPTRGO.SQL                            */
/******************************************************************************/

CREATE OR REPLACE TRIGGER ATUALIZA_PEDIDO
BEFORE DELETE ON ITEMPRODUTO FOR EACH ROW
DECLARE
   V_IDSITITEMPED  ITEMPEDIDO.IDSITITEMPED%TYPE;
   V_QTEXPITEMPED  ITEMPEDIDO.QTEXPITEMPED%TYPE;
   V_QTITEMPED     ITEMPEDIDO.QTITEMPED%TYPE;
   V_VRPELIQEXP    PAREXPEDICAO.VRPELIQEXP%TYPE;
   V_VRFATOCONV    PRODUTO.VRFATOCONV%TYPE;
   V_IDGERPRODEST  PAREXPEDICAO.IDGERPRODEST%TYPE;
   V_QTPARCITEMPED ITEMPEDIDO.QTITEMPED%TYPE;
   V_NRITENS INTEGER;
   V_CDOPERADOR OPERADOR.CDOPERADOR%TYPE;
BEGIN

   IF ((NOT (:OLD.CDFILIALPED IS NULL)) AND
       (NOT (:OLD.NRPEDIDO    IS NULL)) AND
       (NOT (:OLD.NRITEMPED   IS NULL)) ) THEN

      BEGIN
         SELECT MAX(CDOPERADOR)
         INTO V_CDOPERADOR
         FROM ITEMPEDIDO
         WHERE
            CDFILIAL  =  :OLD.CDFILIALPED AND
            NRPEDIDO  =  :OLD.NRPEDIDO AND
            NRITEMPED =  :OLD.NRITEMPED;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_CDOPERADOR := '';
      END;

      BEGIN
          SELECT IDGERPRODEST
          INTO V_IDGERPRODEST
          FROM PAREXPEDICAO
          WHERE CDFILIAL = :OLD.CDFILIALPED;
       EXCEPTION
          WHEN NO_DATA_FOUND THEN
             V_IDGERPRODEST := '1';
       END;

      SELECT MAX(I.IDSITITEMPED),MAX(I.QTEXPITEMPED),MAX(I.QTITEMPED),MAX(P.VRPELIQEXP)
         INTO V_IDSITITEMPED,V_QTEXPITEMPED,V_QTITEMPED,V_VRPELIQEXP
         FROM ITEMPEDIDO I, PAREXPEDICAO P
         WHERE ((:OLD.CDFILIALPED = I.CDFILIAL)    AND
                (:OLD.NRPEDIDO    = I.NRPEDIDO)    AND
                (:OLD.NRITEMPED   = I.NRITEMPED)   AND
                (:OLD.CDFILIALPED = P.CDFILIAL));

      IF (V_IDGERPRODEST = '1') THEN
         IF (V_QTEXPITEMPED - :OLD.QTITEMPROD) >= 0 THEN
            V_QTPARCITEMPED := (V_QTEXPITEMPED - :OLD.QTITEMPROD);
            UPDATE ITEMPEDIDO
            SET QTEXPITEMPED = (V_QTEXPITEMPED - :OLD.QTITEMPROD)
            WHERE ((:OLD.CDFILIALPED = CDFILIAL)    AND
                   (:OLD.NRPEDIDO    = NRPEDIDO)    AND
                   (:OLD.NRITEMPED   = NRITEMPED));
         ELSE
            V_QTPARCITEMPED := 0;
            UPDATE ITEMPEDIDO
            SET QTEXPITEMPED = 0
            WHERE ((:OLD.CDFILIALPED = CDFILIAL)    AND
                   (:OLD.NRPEDIDO    = NRPEDIDO)    AND
                   (:OLD.NRITEMPED   = NRITEMPED));
         END IF;
      ELSE
         IF (V_IDGERPRODEST = '2') THEN
            BEGIN
               SELECT MAX(A.VRFATOCONV)
               INTO V_VRFATOCONV
               FROM PRODUTO A, ITEMPEDIDO I
               WHERE ((A.CDPRODUTO      = I.CDPRODUTO) AND
                      (:OLD.CDFILIALPED = I.CDFILIAL ) AND
                      (:OLD.NRPEDIDO    = I.NRPEDIDO ) AND
                      (:OLD.NRITEMPED   = I.NRITEMPED));
            EXCEPTION
               WHEN NO_DATA_FOUND THEN
                  V_VRFATOCONV := '';
            END;

            IF V_VRFATOCONV IS NULL THEN
               V_VRFATOCONV := 0;
            END IF;
            IF (V_VRFATOCONV <> 0) THEN

               IF (V_QTEXPITEMPED - (:OLD.QTITEMPROD / V_VRFATOCONV)) >= 0 THEN
                  V_QTPARCITEMPED := (V_QTEXPITEMPED - (:OLD.QTITEMPROD / V_VRFATOCONV));
                  UPDATE ITEMPEDIDO
                  SET QTEXPITEMPED = (V_QTEXPITEMPED - (:OLD.QTITEMPROD / V_VRFATOCONV))
                  WHERE ((:OLD.CDFILIALPED = CDFILIAL)    AND
                         (:OLD.NRPEDIDO    = NRPEDIDO)    AND
                         (:OLD.NRITEMPED   = NRITEMPED));
               ELSE

                  V_QTPARCITEMPED := 0;
                  UPDATE ITEMPEDIDO
                  SET QTEXPITEMPED = 0
                  WHERE ((:OLD.CDFILIALPED = CDFILIAL)    AND
                         (:OLD.NRPEDIDO    = NRPEDIDO)    AND
                         (:OLD.NRITEMPED   = NRITEMPED));
               END IF;
            ELSE
               IF (V_QTEXPITEMPED - :OLD.QTITEMPROD) >= 0 THEN
                  V_QTPARCITEMPED := (V_QTEXPITEMPED - :OLD.QTITEMPROD);
                  UPDATE ITEMPEDIDO
                  SET QTEXPITEMPED = (V_QTEXPITEMPED - :OLD.QTITEMPROD)
                  WHERE ((:OLD.CDFILIALPED = CDFILIAL)    AND
                         (:OLD.NRPEDIDO    = NRPEDIDO)    AND
                         (:OLD.NRITEMPED   = NRITEMPED));
               ELSE
                  V_QTPARCITEMPED := 0;
                  UPDATE ITEMPEDIDO
                  SET QTEXPITEMPED = 0
                  WHERE ((:OLD.CDFILIALPED = CDFILIAL)    AND
                         (:OLD.NRPEDIDO    = NRPEDIDO)    AND
                         (:OLD.NRITEMPED   = NRITEMPED));
               END IF;
            END IF;
         ELSE
            V_QTPARCITEMPED := 0;
            UPDATE ITEMPEDIDO
            SET QTEXPITEMPED = 0
            WHERE ((:OLD.CDFILIALPED = CDFILIAL)    AND
                   (:OLD.NRPEDIDO    = NRPEDIDO)    AND
                   (:OLD.NRITEMPED   = NRITEMPED));
         END IF;
      END IF;

      V_NRITENS := 0;

      IF (V_IDSITITEMPED = '4')OR(V_IDSITITEMPED = '6')OR(V_IDSITITEMPED = '7')THEN
         IF (V_QTPARCITEMPED = 0) THEN
            UPDATE ITEMPEDIDO
            SET IDSITITEMPED = '3',
                CDOPERADOR = V_CDOPERADOR
            WHERE ((:OLD.CDFILIALPED = CDFILIAL)    AND
                   (:OLD.NRPEDIDO    = NRPEDIDO)    AND
                   (:OLD.NRITEMPED   = NRITEMPED));
            SELECT COUNT(*)
            INTO V_NRITENS
            FROM
               ITEMPEDIDO
            WHERE
                  (CDFILIAL =  :OLD.CDFILIALPED)
               AND(NRPEDIDO =  :OLD.NRPEDIDO)
               AND(QTEXPITEMPED <> 0);
            IF (V_NRITENS =  0) THEN
               UPDATE PEDIDO
               SET IDSITPEDIDO = '2'
               WHERE
                  ((:OLD.CDFILIALPED = CDFILIAL)AND
                   (:OLD.NRPEDIDO    = NRPEDIDO));
            ELSE
               UPDATE PEDIDO
               SET IDSITPEDIDO = '6'
               WHERE
                  ((:OLD.CDFILIALPED = CDFILIAL)AND
                   (:OLD.NRPEDIDO    = NRPEDIDO));
            END IF;
         ELSE
            IF( V_IDSITITEMPED <> '7') THEN
               UPDATE ITEMPEDIDO
               SET IDSITITEMPED = '7',
                   CDOPERADOR = V_CDOPERADOR
               WHERE ((:OLD.CDFILIALPED = CDFILIAL)    AND
                      (:OLD.NRPEDIDO    = NRPEDIDO)    AND
                      (:OLD.NRITEMPED   = NRITEMPED));
               UPDATE PEDIDO
               SET IDSITPEDIDO = '6'
               WHERE ((:OLD.CDFILIALPED = CDFILIAL)AND
                      (:OLD.NRPEDIDO    = NRPEDIDO));
            END IF;
         END IF;
      END IF;
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('ATUALIZA_PEDIDO','4.11.174'); END;
/

