describe('ZhLayoutImportLayoutController', function(){

    var zhPromise;
    var zhPreferences;
    var messageService;
    var zhLayoutPreferences;
    var zhLayoutWidgetsBuilder;
    var screenService;
    var zhLayoutImportLayoutController;

    beforeEach(function(){
        zhPromise = Q;
        zhPreferences                           = jasmine.createSpyObj('ZhPreferences',             ['getUserID']);
        zhLayoutPreferences                     = jasmine.createSpyObj('ZhLayoutPreferences',       ['saveLayouts', 'updateLayouts', 'factoryFields', 'validateLayoutImport']);
        zhLayoutWidgetsBuilder                  = jasmine.createSpyObj('ZhLayoutWidgetsBuilder',    ['factoryImportLayoutWidget']);
        screenService                           = jasmine.createSpyObj('ScreenService',             ['i18n', 'openPopup', 'closePopup']);
        messageService                          = jasmine.createSpyObj('MessageService',            ['showMessageByCode']);

        zhLayoutImportLayoutController = new ZhLayoutImportLayoutController(messageService, zhLayoutPreferences, zhPreferences, zhLayoutWidgetsBuilder, zhPromise, screenService);
    });

    it('getImportLayoutWidget', function(done){
        var originalImportLayoutWidget = {
            'name': 'zhLayoutImportLayoutWidget'
        };

        zhLayoutWidgetsBuilder.factoryImportLayoutWidget.and.callFake(function(){
            return Q.when(originalImportLayoutWidget);
        });

        zhLayoutImportLayoutController.getImportLayoutWidget().then(function(importLayoutWidget){
            expect(importLayoutWidget).toBe(originalImportLayoutWidget);

            zhLayoutImportLayoutController.getImportLayoutWidget().then(function(importLayoutWidgetSecondCall){
                expect(importLayoutWidget).toBe(importLayoutWidgetSecondCall);
                done();
            });
        });
    });

    it('Import Layout: widget invalid', function(done){
        var listWidget = {
            'id': '1',
            'fields': [{
                'name': 'field_1'
            },{
                'name': 'field_2'
            }]
        };

        var layoutFile = {
            'ID': 999
        };

        var importLayoutWidget = {
            'currentRow': {
                'LABEL_TO_PREFERENCE': 'layout name'
            },
            'isValid': function(){
                return false;
            },
            'configWidget': {
                'listWidget': listWidget
            },
            'fields': [{
                'name': 'layoutFile',
                'value': function(){
                    return [{
                       b64File: 'data:;base64,'+window.btoa(JSON.stringify(layoutFile))
                    }];
                }
            }]
        };

        zhLayoutImportLayoutController.importPreference(importLayoutWidget).then(function(){
            fail('Widget is invalid: should not execute this line');

            done();
        }, function(error){
            expect(error).toEqual({err: 'WIDGET_INVALID'});

            done();
        });
    });

    it('Import Layout: layout file invalid', function(done){
        var listWidget = {
            'id': '1',
            'fields': [{
                'name': 'field_1'
            },{
                'name': 'field_2'
            }]
        };

        var layoutFile = {
            'ID': 999,
            'WIDGET_ID': '2',
            'LABEL_TO_PREFERENCE': 'Layout'
        };

        var importLayoutWidget = {
            'currentRow': {
                'LABEL_TO_PREFERENCE': 'layout name'
            },
            'isValid': function(){
                return true;
            },
            'configWidget': {
                'listWidget': listWidget,
                'dataSource': {
                    'data': [{
                        'ID': 999,
                        'LABEL_TO_PREFERENCE': 'Layout'
                    }]
                }
            },
            'fields': [{
                'name': 'layoutFile',
                'value': function(){
                    return [{
                       b64File: 'data:;base64,'+window.btoa(JSON.stringify(layoutFile))
                    }];
                }
            }]
        };

        zhLayoutPreferences.validateLayoutImport.and.callFake(function(){
            return false;
        });

        zhLayoutImportLayoutController.importPreference(importLayoutWidget).then(function(){
            fail('Layout file is invalid: should not execute this line');

            done();
        }, function(error){
            expect(error).toEqual({err: 'LAYOUT_FILE_INVALID'});

            done();
        });
    });

    it('Import Layout', function(done){
        var userID = 'user-1';

        var listWidget = {
            'id': '1',
            'fields': [{
                'name': 'field_1'
            },{
                'name': 'field_2'
            }]
        };

        var layoutFile = {
            'ID': 999,
            'WIDGET_ID': '1',
            'LABEL_TO_PREFERENCE': 'Layout',
            '__is_new': true,
            '__generate_id': false,
            'LAYOUT_CHANGES': undefined,
            'USER_ID': userID
        };

        var importLayoutWidget = {
            'currentRow': {
                'LABEL_TO_PREFERENCE': 'layout name'
            },
            'isValid': function(){
                return true;
            },
            'configWidget': {
                'listWidget': listWidget,
                'dataSource': {
                    'data': []
                },
                'refreshWidget': function(){}
            },
            'fields': [{
                'name': 'layoutFile',
                'value': function(){
                    return [{
                       b64File: 'data:;base64,'+window.btoa(JSON.stringify(layoutFile))
                    }];
                }
            }]
        };

        zhPreferences.getUserID.and.callFake(function(){
            return Q.when(userID);
        });

        zhLayoutPreferences.saveLayouts.and.callFake(function(){
            return Q.when([{'ID': 1}]);
        });

        screenService.closePopup.and.callFake(function(){
            return Q.when('{}');
        });

        zhLayoutPreferences.validateLayoutImport.and.callFake(function(){
            return true;
        });

        spyOn(importLayoutWidget.configWidget, 'refreshWidget');

        zhLayoutImportLayoutController.importPreference(importLayoutWidget).then(function(){
            expect(zhLayoutPreferences.saveLayouts).toHaveBeenCalledWith([layoutFile]);
            expect(screenService.closePopup).toHaveBeenCalled();
            expect(zhLayoutPreferences.updateLayouts).toHaveBeenCalledWith(listWidget.id, importLayoutWidget.configWidget.dataSource);
            expect(importLayoutWidget.configWidget.refreshWidget).toHaveBeenCalled();

            done();
        });
    });

    it('Import Layout: save error', function(done){
        var userID = 'user-1';

        var listWidget = {
            'id': '1',
            'fields': [{
                'name': 'field_1'
            },{
                'name': 'field_2'
            }]
        };

        var layoutFile = {
            'ID': 999,
            'WIDGET_ID': '1',
            'LABEL_TO_PREFERENCE': 'Layout',
            '__is_new': true,
            '__generate_id': false,
            'LAYOUT_CHANGES': undefined,
            'USER_ID': userID
        };

        var importLayoutWidget = {
            'currentRow': {
                'LABEL_TO_PREFERENCE': 'layout name'
            },
            'isValid': function(){
                return true;
            },
            'configWidget': {
                'listWidget': listWidget,
                'dataSource': {
                    'data': []
                },
                'refreshWidget': function(){}
            },
            'fields': [{
                'name': 'layoutFile',
                'value': function(){
                    return [{
                       b64File: 'data:;base64,'+window.btoa(JSON.stringify(layoutFile))
                    }];
                }
            }]
        };

        zhPreferences.getUserID.and.callFake(function(){
            return Q.when(userID);
        });

        zhLayoutPreferences.saveLayouts.and.callFake(function(){
            return Q.reject(new Error('save error'));
        });

        screenService.closePopup.and.callFake(function(){
            return Q.when('{}');
        });

        zhLayoutPreferences.validateLayoutImport.and.callFake(function(){
            return true;
        });

        spyOn(importLayoutWidget.configWidget, 'refreshWidget');

        zhLayoutImportLayoutController.importPreference(importLayoutWidget).then(function(){
            expect(zhLayoutPreferences.saveLayouts).toHaveBeenCalledWith([layoutFile]);

            expect(screenService.closePopup).not.toHaveBeenCalled();
            expect(zhLayoutPreferences.updateLayouts).not.toHaveBeenCalled();
            expect(importLayoutWidget.configWidget.refreshWidget).not.toHaveBeenCalled();

            expect(messageService.showMessageByCode).toHaveBeenCalledWith('zh-layout-preferences#save_error', {'ERROR': 'save error'});

            done();
        });
    });
});